==> net.bluemind.p2.platform-4.9.3879.zip: net/bluemind/resource/api/gwt/serder/EventInfoGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.resource.api.gwt.serder;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class EventInfoGwtSerDer implements GwtSerDer<net.bluemind.resource.api.EventInfo> {

	public EventInfoGwtSerDer( ) {
	}

	@Override
	public net.bluemind.resource.api.EventInfo deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.resource.api.EventInfo ret = new net.bluemind.resource.api.EventInfo();
		deserializeTo(ret, json);

		return ret;
	}

	public void deserializeTo(net.bluemind.resource.api.EventInfo ret, JSONObject json) {

	}

	@Override
	public JSONValue serialize(net.bluemind.resource.api.EventInfo o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.resource.api.EventInfo o, JSONObject ret) {

	}
}

==> net.bluemind.p2.platform-5.4.2760.zip: net/bluemind/resource/api/gwt/serder/EventInfoGwtSerDer.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.resource.api.gwt.serder;

import java.util.Set;
import java.util.HashSet;

import net.bluemind.core.commons.gwt.GwtSerDer;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;

import com.google.gwt.json.client.JSONObject;
import com.google.gwt.json.client.JSONValue;

public class EventInfoGwtSerDer implements GwtSerDer<net.bluemind.resource.api.EventInfo> {

	public EventInfoGwtSerDer( ) {
	}

	@Override
	public net.bluemind.resource.api.EventInfo deserialize(JSONValue value) {
		if( value == null ) {
			return null;
		}

		JSONObject json = value.isObject();
		if (json == null) {
			return null;
		}

		net.bluemind.resource.api.EventInfo ret = new net.bluemind.resource.api.EventInfo();
		deserializeTo(ret, json);
		return ret;
	}

	public void deserializeTo(net.bluemind.resource.api.EventInfo ret, JSONObject json) {
	}

	public void deserializeTo(net.bluemind.resource.api.EventInfo ret, JSONObject json, Set<String> childPropertiesToIgnore) {
	}


	@Override
	public JSONValue serialize(net.bluemind.resource.api.EventInfo o) {
		if (o == null) {
			return null;
		}

		JSONObject ret = new JSONObject();
		serializeTo( o, ret);
		return ret;
	}

	public void serializeTo(net.bluemind.resource.api.EventInfo o, JSONObject ret) {

	}

	public void serializeTo(net.bluemind.resource.api.EventInfo o, JSONObject ret, Set<String> childPropertiesToIgnore) {

	}


	public Set<String> propertiesToIgnore() {
		return new HashSet<>();
	}
}
